@@ -7,7 +7,7 @@ use Filter::signatures;
 no warnings 'experimental::signatures';
 use feature 'signatures';
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 with 'Future::HTTP::Handler';
 
@@ -42,6 +42,8 @@ sub BUILDARGS {
     }
 }
 
+sub is_async { !1 }
+
 sub _ae_from_http_tiny( $self, $result, $url ) {
     # Convert the result back to a future
     my( $body )        = delete $result->{content};
@@ -124,6 +126,10 @@ sub http_post($self,$url,$body,%options) {
 
 Creates a new instance of the HTTP client.
 
+=head2 C<< $ua->is_async() >>
+
+Returns false, because this backend is synchronous.
+
 =head2 C<< $ua->http_get($url, %options) >>
 
     $ua->http_get('http://example.com/',
@@ -229,7 +235,7 @@ Max Maischein C<corion@cpan.org>
 
 =head1 COPYRIGHT (c)
 
-Copyright 2016-2019 by Max Maischein C<corion@cpan.org>.
+Copyright 2016-2020 by Max Maischein C<corion@cpan.org>.
 
 =head1 LICENSE
 
